@@ -7,12 +7,15 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
+#include "stdafx.h"
+#include <winsock2.h>
+#include <ws2tcpip.h>
+
 extern "C" {
 #include <afs/param.h>
 #include <afs/stds.h>
 }
 
-#include "stdafx.h"
 #include "submounts_dlg.h"
 #include "add_submount_dlg.h"
 #include "msgs.h"
@@ -42,13 +45,13 @@ static CSubmountInfo *ReadSubmtInfo(const CString& strShareName)
 
 	DWORD len;
 
-	char pathName[1024];
+	TCHAR pathName[1024];
 
     HKEY hkSubmounts;
     RegCreateKeyEx( HKEY_LOCAL_MACHINE, 
-                    AFSREG_CLT_OPENAFS_SUBKEY "\\Submounts",
+                    AFSREG_CLT_OPENAFS_SUBKEY TEXT("\\Submounts"),
                     0, 
-                    "AFS", 
+                    TEXT("AFS"), 
                     REG_OPTION_NON_VOLATILE,
                     (IsWow64()?KEY_WOW64_64KEY:0)|KEY_READ,
                     NULL, 
@@ -58,7 +61,7 @@ static CSubmountInfo *ReadSubmtInfo(const CString& strShareName)
     DWORD dwType;
     DWORD status;
     len = sizeof(pathName);
-    status = RegQueryValueEx( hkSubmounts, (LPCSTR)PCCHAR(strShareName), 0,
+    status = RegQueryValueEx( hkSubmounts, strShareName, 0,
                               &dwType, (LPBYTE)pathName, &len);
     RegCloseKey( hkSubmounts );
 
@@ -167,9 +170,9 @@ BOOL CSubmountsDlg::FillSubmtList()
     DWORD dwSubmounts;
 
     RegCreateKeyEx( HKEY_LOCAL_MACHINE, 
-                    AFSREG_CLT_OPENAFS_SUBKEY "\\Submounts",
+                    AFSREG_CLT_OPENAFS_SUBKEY TEXT("\\Submounts"),
                     0, 
-                    "AFS", 
+                    TEXT("AFS"), 
                     REG_OPTION_NON_VOLATILE,
                     (IsWow64()?KEY_WOW64_64KEY:0)|KEY_READ|KEY_WRITE|KEY_QUERY_VALUE,
                     NULL, 
@@ -192,7 +195,7 @@ BOOL CSubmountsDlg::FillSubmtList()
 
 
     for ( dwIndex = 0; dwIndex < dwSubmounts; dwIndex ++ ) {
-        char submountName[256];
+        TCHAR submountName[256];
         DWORD submountNameLen = sizeof(submountName);
 
         RegEnumValue( hkSubmounts, dwIndex, submountName, &submountNameLen, NULL,
@@ -219,7 +222,7 @@ void CSubmountsDlg::OnDelete()
 
 	ASSERT(!strSubmt.IsEmpty());
 
-	strShareName = strSubmt.SpanExcluding("=");
+	strShareName = strSubmt.SpanExcluding(_T("="));
 
 	if (ShowMessageBox(IDS_REALLY_DELETE_SUBMT, MB_YESNO | MB_ICONQUESTION, IDS_REALLY_DELETE_SUBMT, strShareName) != IDYES)
 		return;
@@ -249,17 +252,18 @@ static BOOL AddSubmt(CSubmountInfo *pInfo)
 
     HKEY hkSubmounts;
     RegCreateKeyEx( HKEY_LOCAL_MACHINE, 
-                    AFSREG_CLT_OPENAFS_SUBKEY "\\Submounts",
+                    AFSREG_CLT_OPENAFS_SUBKEY TEXT("\\Submounts"),
                     0, 
-                    "AFS", 
+                    TEXT("AFS"), 
                     REG_OPTION_NON_VOLATILE,
                     (IsWow64()?KEY_WOW64_64KEY:0)|KEY_WRITE,
                     NULL, 
                     &hkSubmounts,
                     NULL );
 
-    DWORD status = RegSetValueEx( hkSubmounts, PCCHAR(pInfo->GetShareName()), 0, REG_SZ,
-                   (const BYTE *)PCCHAR(pInfo->GetPathName()), strlen(PCCHAR(pInfo->GetPathName())) + 1);
+    DWORD status = RegSetValueEx( hkSubmounts, pInfo->GetShareName(), 0, REG_SZ,
+                                  (const BYTE *)(const TCHAR *) pInfo->GetPathName(),
+                                  pInfo->GetPathName().GetLength() + 1);
 
     RegCloseKey(hkSubmounts);
 	return (status == ERROR_SUCCESS);
@@ -271,16 +275,16 @@ static BOOL DeleteSubmt(CSubmountInfo *pInfo)
 
     HKEY hkSubmounts;
     RegCreateKeyEx( HKEY_LOCAL_MACHINE, 
-                    AFSREG_CLT_OPENAFS_SUBKEY "\\Submounts",
+                    AFSREG_CLT_OPENAFS_SUBKEY TEXT("\\Submounts"),
                     0, 
-                    "AFS", 
+                    TEXT("AFS"), 
                     REG_OPTION_NON_VOLATILE,
                     (IsWow64()?KEY_WOW64_64KEY:0)|KEY_WRITE,
                     NULL, 
                     &hkSubmounts,
                     NULL );
 
-    DWORD status = RegDeleteValue( hkSubmounts, PCCHAR(pInfo->GetShareName()));
+    DWORD status = RegDeleteValue( hkSubmounts, pInfo->GetShareName());
 
     RegCloseKey(hkSubmounts);
 	return (status == ERROR_SUCCESS);
@@ -322,7 +326,7 @@ void CSubmountsDlg::OnChange()
 
 	ASSERT(!strSubmt.IsEmpty());
 
-	strShareName = strSubmt.SpanExcluding("=");
+	strShareName = strSubmt.SpanExcluding(_T("="));
 
 	CSubmountInfo *pInfo = FindWork(strShareName);
 	if (pInfo != 0)
