@@ -10,53 +10,26 @@
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/IRIX/osi_file.c,v 1.11.14.2 2007/12/13 19:18:32 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
 #include "afs/afs_stats.h"	/* afs statistics */
 
-struct  AFS_UCRED afs_osi_cred;
+afs_ucred_t afs_osi_cred;
 int afs_osicred_initialized = 0;
 afs_lock_t afs_xosi;		/* lock is for tvattr */
 extern struct osi_dev cacheDev;
 extern struct vfs *afs_cacheVfsp;
 
-
-/* As of 6.2, we support either XFS or EFS clients. osi_UFSOpen
- * now vectors to the correct EFS or XFS function. If new functionality is
- * added which accesses the inode, that will also need EFS/XFS variants.
- */
-#ifdef AFS_SGI_EFS_IOPS_ENV
 vnode_t *
-afs_EFSIGetVnode(ino_t ainode)
-{
-    struct inode *ip;
-    int error;
-
-    if ((error = igetinode(afs_cacheVfsp, (dev_t) cacheDev.dev, ainode, &ip))) {
-	osi_Panic("afs_EFSIGetVnode: igetinode failed, error=%d", error);
-    }
-    /* We don't care about atimes on the cache files, so disable them.  I'm not
-     * sure that this is the right place to do this: it should be *after* readi 
-     * and getattr and stuff. 
-     */
-    ip->i_flags &= ~(ISYN | IACC);
-    iunlock(ip);
-    return (EFS_ITOV(ip));
-}
-#endif /* AFS_SGI_EFS_IOPS_ENV */
-
-vnode_t *
-afs_XFSIGetVnode(ino_t ainode)
+afs_XFSIGetVnode(afs_dcache_id_t *ainode)
 {
     struct xfs_inode *ip;
     int error;
     vnode_t *vp;
 
     if ((error =
-	 xfs_igetinode(afs_cacheVfsp, (dev_t) cacheDev.dev, ainode, &ip))) {
+	 xfs_igetinode(afs_cacheVfsp, (dev_t) cacheDev.dev, ainode->ufs, &ip))) {
 	osi_Panic("afs_XFSIGetVnode: xfs_igetinode failed, error=%d", error);
     }
     vp = XFS_ITOV(ip);
@@ -65,7 +38,7 @@ afs_XFSIGetVnode(ino_t ainode)
 
 /* Force to 64 bits, even for EFS filesystems. */
 void *
-osi_UFSOpen(ino_t ainode)
+osi_UFSOpen(afs_dcache_id_t *ainode)
 {
     struct inode *ip;
     register struct osi_file *afile = NULL;
@@ -78,18 +51,17 @@ osi_UFSOpen(ino_t ainode)
     }
     if (!afs_osicred_initialized) {
 	/* valid for alpha_osf, SunOS, Ultrix */
-	memset((char *)&afs_osi_cred, 0, sizeof(struct AFS_UCRED));
+	memset(&afs_osi_cred, 0, sizeof(afs_ucred_t));
 	crhold(&afs_osi_cred);	/* don't let it evaporate, since it is static */
 	afs_osicred_initialized = 1;
     }
     afile = (struct osi_file *)osi_AllocSmallSpace(sizeof(struct osi_file));
     AFS_GUNLOCK();
-    afile->vnode = AFS_SGI_IGETVNODE(ainode);
+    afile->vnode = AFS_SGI_IGETVNODE(ainode->ufs);
     AFS_GLOCK();
     afile->size = VnodeToSize(afile->vnode);
     afile->offset = 0;
     afile->proc = (int (*)())0;
-    afile->inum = ainode;	/* for hint validity checking */
     return (void *)afile;
 }
 
@@ -99,7 +71,7 @@ afs_osi_Stat(register struct osi_file *afile, register struct osi_stat *astat)
     register afs_int32 code;
     struct vattr tvattr;
     AFS_STATCNT(osi_Stat);
-    MObtainWriteLock(&afs_xosi, 320);
+    ObtainWriteLock(&afs_xosi, 320);
     AFS_GUNLOCK();
     tvattr.va_mask = AT_SIZE | AT_BLKSIZE | AT_MTIME | AT_ATIME;
     AFS_VOP_GETATTR(afile->vnode, &tvattr, 0, &afs_osi_cred, code);
@@ -109,7 +81,7 @@ afs_osi_Stat(register struct osi_file *afile, register struct osi_stat *astat)
 	astat->mtime = tvattr.va_mtime.tv_sec;
 	astat->atime = tvattr.va_atime.tv_sec;
     }
-    MReleaseWriteLock(&afs_xosi);
+    ReleaseWriteLock(&afs_xosi);
     return code;
 }
 
@@ -128,7 +100,7 @@ osi_UFSClose(register struct osi_file *afile)
 int
 osi_UFSTruncate(register struct osi_file *afile, afs_int32 asize)
 {
-    struct AFS_UCRED *oldCred;
+    afs_ucred_t *oldCred;
     struct vattr tvattr;
     register afs_int32 code;
     struct osi_stat tstat;
@@ -142,35 +114,23 @@ osi_UFSTruncate(register struct osi_file *afile, afs_int32 asize)
     code = afs_osi_Stat(afile, &tstat);
     if (code || tstat.size <= asize)
 	return code;
-    MObtainWriteLock(&afs_xosi, 321);
+    ObtainWriteLock(&afs_xosi, 321);
     AFS_GUNLOCK();
     tvattr.va_mask = AT_SIZE;
     tvattr.va_size = asize;
     AFS_VOP_SETATTR(afile->vnode, &tvattr, 0, &afs_osi_cred, code);
     AFS_GLOCK();
-    MReleaseWriteLock(&afs_xosi);
+    ReleaseWriteLock(&afs_xosi);
     return code;
 }
 
-#ifdef AFS_SGI_EFS_IOPS_ENV
-void
-osi_DisableAtimes(struct vnode *avp)
-{
-    if (afs_CacheFSType == AFS_SGI_EFS_CACHE) {
-	struct inode *ip = EFS_VTOI(avp);
-	ip->i_flags &= ~IACC;
-    }
-
-}
-#endif /* AFS_SGI_EFS_IOPS_ENV */
-
 
 /* Generic read interface */
 int
 afs_osi_Read(register struct osi_file *afile, int offset, void *aptr,
 	     afs_int32 asize)
 {
-    struct AFS_UCRED *oldCred;
+    afs_ucred_t *oldCred;
     ssize_t resid;
     register afs_int32 code;
     register afs_int32 cnt1 = 0;
@@ -197,9 +157,6 @@ afs_osi_Read(register struct osi_file *afile, int offset, void *aptr,
     if (code == 0) {
 	code = asize - resid;
 	afile->offset += code;
-#ifdef AFS_SGI_EFS_IOPS_ENV
-	osi_DisableAtimes(afile->vnode);
-#endif /* AFS_SGI_EFS_IOPS_ENV */
     } else {
 	afs_Trace2(afs_iclSetp, CM_TRACE_READFAILED, ICL_TYPE_INT32, resid,
 		   ICL_TYPE_INT32, code);
@@ -213,7 +170,7 @@ int
 afs_osi_Write(register struct osi_file *afile, afs_int32 offset, void *aptr,
 	      afs_int32 asize)
 {
-    struct AFS_UCRED *oldCred;
+    afs_ucred_t *oldCred;
     ssize_t resid;
     register afs_int32 code;
     AFS_STATCNT(osi_Write);
