@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/LINUX/osi_sleep.c,v 1.30.4.3 2007/06/12 05:44:05 rra Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
@@ -84,11 +82,7 @@ typedef struct afs_event {
     int seq;			/* Sequence number: this is incremented
 				 * by wakeup calls; wait will not return until
 				 * it changes */
-#if defined(AFS_LINUX24_ENV)
     wait_queue_head_t cond;
-#else
-    struct wait_queue *cond;
-#endif
 } afs_event_t;
 
 #define HASHSIZE 128
@@ -148,11 +142,7 @@ afs_addevent(char *event)
     afs_evhashcnt++;
     newp->next = afs_evhasht[hashcode];
     afs_evhasht[hashcode] = newp;
-#if defined(AFS_LINUX24_ENV)
     init_waitqueue_head(&newp->cond);
-#else
-    init_waitqueue(&newp->cond);
-#endif
     newp->seq = 0;
     newp->event = &dummyV;	/* Dummy address for new events */
     newp->refcount = 0;
@@ -196,7 +186,6 @@ afs_osi_SleepSig(void *event)
 	AFS_ASSERT_GLOCK();
 	AFS_GUNLOCK();
 	schedule();
-#ifdef AFS_LINUX26_ENV
 #ifdef CONFIG_PM
 	if (
 #ifdef PF_FREEZE
@@ -218,7 +207,6 @@ afs_osi_SleepSig(void *event)
 #else
 	    refrigerator();
 #endif
-#endif
 #endif
 	AFS_GLOCK();
 	if (signal_pending(current)) {
@@ -298,7 +286,6 @@ osi_TimedSleep(char *event, afs_int32 ams, int aintok)
 	    code = EINTR;
     } else
 	schedule_timeout(ticks);
-#ifdef AFS_LINUX26_ENV
 #ifdef CONFIG_PM
     if (
 #ifdef PF_FREEZE
@@ -320,7 +307,6 @@ osi_TimedSleep(char *event, afs_int32 ams, int aintok)
 #else
 	refrigerator();
 #endif
-#endif
 #endif
 
     AFS_GLOCK();
