@@ -90,8 +90,6 @@ afs_CopyOutAttrs(register struct vcache *avc, register struct vattr *attrs)
     attrs->va_gid = fakedir ? 0 : avc->f.m.Group;	/* yeah! */
 #if defined(AFS_SUN56_ENV)
     attrs->va_fsid = avc->v.v_vfsp->vfs_fsid.val[0];
-#elif defined(AFS_OSF_ENV)
-    attrs->va_fsid = avc->v.v_mount->m_stat.f_fsid.val[0];
 #elif defined(AFS_DARWIN80_ENV)
     VATTR_RETURN(attrs, va_fsid, vfs_statfs(vnode_mount(AFSTOV(avc)))->f_fsid.val[0]);
 #elif defined(AFS_DARWIN70_ENV)
@@ -142,7 +140,7 @@ afs_CopyOutAttrs(register struct vcache *avc, register struct vattr *attrs)
     attrs->va_atime.tv_usec = attrs->va_mtime.tv_usec =
 	attrs->va_ctime.tv_usec = (hgetlo(avc->f.m.DataVersion) & 0x7ffff);
 #endif
-#if defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV) || defined(AFS_OSF_ENV)
+#if defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
     attrs->va_flags = 0;
 #endif
 #if defined(AFS_SGI_ENV) || defined(AFS_SUN5_ENV)
@@ -160,7 +158,7 @@ afs_CopyOutAttrs(register struct vcache *avc, register struct vattr *attrs)
      * Below return 0 (and not 1) blocks if the file is zero length. This conforms
      * better with the other filesystems that do return 0.      
      */
-#if defined(AFS_OSF_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
+#if defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
     attrs->va_bytes = (attrs->va_size ? (attrs->va_size + 1023) : 1024);
 #ifdef	va_bytes_rsv
     attrs->va_bytes_rsv = -1;
@@ -182,16 +180,15 @@ afs_CopyOutAttrs(register struct vcache *avc, register struct vattr *attrs)
 #if	defined(AFS_SUN5_ENV) || defined(AFS_SGI_ENV)
 int
 afs_getattr(OSI_VC_DECL(avc), struct vattr *attrs, int flags,
-	    AFS_UCRED *acred)
+	    afs_ucred_t *acred)
 #else
 int
-afs_getattr(OSI_VC_DECL(avc), struct vattr *attrs, AFS_UCRED *acred)
+afs_getattr(OSI_VC_DECL(avc), struct vattr *attrs, afs_ucred_t *acred)
 #endif
 {
     afs_int32 code;
     struct vrequest treq;
     struct unixuser *au;
-    int inited = 0;
     OSI_VC_CONVERT(avc);
 
     AFS_STATCNT(afs_getattr);
@@ -215,15 +212,23 @@ afs_getattr(OSI_VC_DECL(avc), struct vattr *attrs, AFS_UCRED *acred)
 	afs_PutFakeStat(&fakestat);
 	return code;
     }
+
+#if defined(AFS_SUN5_ENV) || defined(AFS_DARWIN_ENV) && !defined(AFS_DARWIN80_ENV)
 #if defined(AFS_SUN5_ENV)
-    if (flags & ATTR_HINT) {
-	code = afs_CopyOutAttrs(avc, attrs);
-	return code;
-    }
+	if (flags & ATTR_HINT)
+#else
+	if (avc->f.states & CUBCinit)
 #endif
-#if defined(AFS_DARWIN_ENV) && !defined(AFS_DARWIN80_ENV)
-    if (avc->f.states & CUBCinit) {
-	code = afs_CopyOutAttrs(avc, attrs);
+    {
+	if (!(code = afs_InitReq(&treq, acred))) {
+	    if (vType(avc) != VDIR && vType(avc) != VLNK
+	        !afs_AccessOK(avc, PRSFS_READ, &treq, DONT_CHECK_MODE_BITS)) {
+
+		code = EACCES;
+	    }
+	    if (!code)
+		code = afs_CopyOutAttrs(avc, attrs);
+	}
 	return code;
     }
 #endif
@@ -237,13 +242,11 @@ afs_getattr(OSI_VC_DECL(avc), struct vattr *attrs, AFS_UCRED *acred)
     if (afs_shuttingdown)
 	return EIO;
 
-    if (!(avc->f.states & CStatd)) {
-	if (!(code = afs_InitReq(&treq, acred))) {
-	    code = afs_VerifyVCache2(avc, &treq);
-	    inited = 1;
-	}
-    } else
-	code = 0;
+    code = afs_InitReq(&treq, acred);
+
+    if (code == 0 && !(avc->f.states & CStatd)) {
+	code = afs_VerifyVCache2(avc, &treq);
+    }
 
 #ifdef AFS_BOZONLOCK_ENV
     if (code == 0)
@@ -251,17 +254,17 @@ afs_getattr(OSI_VC_DECL(avc), struct vattr *attrs, AFS_UCRED *acred)
     afs_BozonUnlock(&avc->pvnLock, avc);
 #endif
 
+    if (code == 0 && vType(avc) != VDIR && vType(avc) != VLNK &&
+        !afs_AccessOK(avc, PRSFS_READ, &treq, DONT_CHECK_MODE_BITS)) {
+
+	code = EACCES;
+    }
 
     if (code == 0) {
 	osi_FlushText(avc);	/* only needed to flush text if text locked last time */
 	code = afs_CopyOutAttrs(avc, attrs);
 
 	if (afs_nfsexporter) {
-	    if (!inited) {
-		if ((code = afs_InitReq(&treq, acred)))
-		    return code;
-		inited = 1;
-	    }
 	    if (AFS_NFSXLATORREQ(acred)) {
 		if ((vType(avc) != VDIR)
 		    && !afs_AccessOK(avc, PRSFS_READ, &treq,
@@ -438,11 +441,11 @@ afs_VAttrToAS(register struct vcache *avc, register struct vattr *av,
 #if defined(AFS_SUN5_ENV) || defined(AFS_SGI_ENV)
 int
 afs_setattr(OSI_VC_DECL(avc), register struct vattr *attrs, int flags,
-	    AFS_UCRED *acred)
+	    afs_ucred_t *acred)
 #else
 int
 afs_setattr(OSI_VC_DECL(avc), register struct vattr *attrs,
-	    AFS_UCRED *acred)
+	    afs_ucred_t *acred)
 #endif
 {
     struct vrequest treq;
@@ -494,7 +497,7 @@ afs_setattr(OSI_VC_DECL(avc), register struct vattr *attrs,
     if (attrs->va_mask & ATTR_SIZE) {
 #elif	defined(AFS_SUN5_ENV) || defined(AFS_SGI_ENV)
     if (attrs->va_mask & AT_SIZE) {
-#elif	defined(AFS_OSF_ENV) || defined(AFS_XBSD_ENV)
+#elif	defined(AFS_XBSD_ENV)
     if (attrs->va_size != VNOVAL) {
 #elif	defined(AFS_AIX41_ENV)
     if (attrs->va_size != -1) {
@@ -532,7 +535,7 @@ afs_setattr(OSI_VC_DECL(avc), register struct vattr *attrs,
     if (attrs->va_mask & ATTR_SIZE) {
 #elif	defined(AFS_SUN5_ENV) || defined(AFS_SGI_ENV)
     if (attrs->va_mask & AT_SIZE) {
-#elif	defined(AFS_OSF_ENV) || defined(AFS_XBSD_ENV)
+#elif	defined(AFS_XBSD_ENV)
     if (attrs->va_size != VNOVAL) {
 #elif	defined(AFS_AIX41_ENV)
     if (attrs->va_size != -1) {
