@@ -30,6 +30,7 @@
 #define AFS_SUN58_ENV		1
 #define AFS_SUN59_ENV		1
 #define AFS_SUN510_ENV		1
+#define AFS_SUN511_ENV		1
 #define AFS_BOZONLOCK_ENV       1
 #define AFS_X86_ENV		1
 
@@ -58,9 +59,9 @@
 #define AFS_MOUNT_AFS		"afs"
 
 /* Machine / Operating system information */
-#define sys_sunx86_510		1
-#define SYS_NAME		"sunx86_510"
-#define SYS_NAME_ID		SYS_NAME_ID_sunx86_510
+#define sys_sunx86_511		1
+#define SYS_NAME		"sunx86_511"
+#define SYS_NAME_ID		SYS_NAME_ID_sunx86_511
 #define AFSLITTLE_ENDIAN	1
 #define AFS_HAVE_FFS		1	/* Use system's ffs. */
 #define AFS_HAVE_VXFS		1	/* Support cache on Veritas vxfs file system */
@@ -83,7 +84,6 @@
 /* sun definitions here */
 #define	AFS_UIOFMODE		1	/* Only in afs/afs_vnodeops.c (afs_ustrategy) */
 #define	AFS_SYSVLOCK		1	/* sys v locking supported */
-/*#define	AFS_USEBUFFERS	1*/
 #define	afsio_iov		uio_iov
 #define	afsio_iovcnt		uio_iovcnt
 #define	afsio_offset		uio_loffset
@@ -156,9 +156,9 @@
 #define AFS_MOUNT_AFS		1
 
 /* Machine / Operating system information */
-#define sys_sunx86_510          1
-#define SYS_NAME                "sunx86_510"
-#define SYS_NAME_ID             SYS_NAME_ID_sunx86_510
+#define sys_sunx86_511         1
+#define SYS_NAME                "sunx86_511"
+#define SYS_NAME_ID             SYS_NAME_ID_sunx86_511
 #define AFSLITTLE_ENDIAN	1
 #define AFS_HAVE_FFS            1	/* Use system's ffs. */
 #define AFS_HAVE_STATVFS	0	/* System doesn't support statvfs */
@@ -167,7 +167,6 @@
 #ifdef KERNEL
 #define	AFS_UIOFMODE		1	/* Only in afs/afs_vnodeops.c (afs_ustrategy) */
 #define	AFS_SYSVLOCK		1	/* sys v locking supported */
-/*#define	AFS_USEBUFFERS	1*/
 #define	afsio_iov		uio_iov
 #define	afsio_iovcnt		uio_iovcnt
 #define	afsio_offset		uio_offset
